@@ -2,7 +2,7 @@
     SPDX-License-Identifier: GPL-2.0-or-later
 
     SPDX-FileCopyrightText: 2003 Brian Thomas <thomas@mail630.gsfc.nasa.gov>
-    SPDX-FileCopyrightText: 2004-2021 Umbrello UML Modeller Authors <umbrello-devel@kde.org>
+    SPDX-FileCopyrightText: 2004-2022 Umbrello UML Modeller Authors <umbrello-devel@kde.org>
 */
 
 // own header
@@ -102,11 +102,11 @@ QString CodeDocument::getPath () const
     path = path.simplified();
 
     // Replace all blanks with underscore
-    path.replace(QRegExp(QLatin1String(" ")), QLatin1String("_"));
+    path.replace(QRegExp(QStringLiteral(" ")), QStringLiteral("_"));
 
     // this allows multiple directory paths (ala Java, some other languages)
     // in from the package specification
-    path.replace(QRegExp(QLatin1String("\\.")), QLatin1String("/"));
+    path.replace(QRegExp(QStringLiteral("\\.")), QStringLiteral("/"));
     // Simple hack!.. but this is more or less language
     // dependent and should probably be commented out.
     // Still, as a general default it may be useful -b.t.
@@ -191,9 +191,9 @@ QString CodeDocument::getUniqueTag (const QString& prefix)
 {
     QString tag = prefix ;
     if(tag.isEmpty())
-        tag += QLatin1String("tblock");
+        tag += QStringLiteral("tblock");
 
-    tag = tag + QLatin1String("_0");
+    tag = tag + QStringLiteral("_0");
     int number = m_lastTagIndex;
     for (; findTextBlockByTag(tag, true); ++number) {
         tag = prefix + QLatin1Char('_') + QString::number(number);
@@ -230,8 +230,8 @@ bool CodeDocument::insertTextBlock(TextBlock * newBlock, TextBlock * existingBlo
                 return true; // found, and inserted, otherwise keep going
         }
         // ugh. where is the child block?
-        uWarning() << " Warning: couldnt insert text block (tag:" << newBlock->getTag()
-                   << "). Reference text block (tag:" << existingBlock->getTag() << ") not found.";
+        logWarn2("couldnt insert text block (tag %1). Reference text block (tag %2) not found.",
+                 newBlock->getTag(), existingBlock->getTag());
         return false;
     }
 
@@ -278,10 +278,10 @@ void CodeDocument::updateHeader ()
     //try to find a heading file (license, comments, etc) then extract its text
     QString headingText = UMLApp::app()->commonPolicy()->getHeadingFile(getFileExtension());
 
-    headingText.replace(QRegExp(QLatin1String("%filename%")), getFileName()+getFileExtension());
-    headingText.replace(QRegExp(QLatin1String("%filepath%")), getPath());
-    headingText.replace(QRegExp(QLatin1String("%time%")), QTime::currentTime().toString());
-    headingText.replace(QRegExp(QLatin1String("%date%")), QDate::currentDate().toString());
+    headingText.replace(QRegExp(QStringLiteral("%filename%")), getFileName()+getFileExtension());
+    headingText.replace(QRegExp(QStringLiteral("%filepath%")), getPath());
+    headingText.replace(QRegExp(QStringLiteral("%time%")), QTime::currentTime().toString());
+    headingText.replace(QRegExp(QStringLiteral("%date%")), QDate::currentDate().toString());
 
     getHeader()->setText(headingText);
 
@@ -342,7 +342,7 @@ void CodeDocument::resetTextBlocks()
  * Load params from the appropriate XMI element node.
  * @param root   the starting point for loading
  */
-void CodeDocument::loadFromXMI1 (QDomElement & root)
+void CodeDocument::loadFromXMI (QDomElement & root)
 {
     setAttributesFromNode(root);
 }
@@ -357,20 +357,20 @@ void CodeDocument::setAttributesOnNode (QXmlStreamWriter& writer)
     CodeGenObjectWithTextBlocks::setAttributesOnNode(writer);
 
     // now set local attributes/fields
-    writer.writeAttribute(QLatin1String("fileName"), getFileName());
-    writer.writeAttribute(QLatin1String("fileExt"), getFileExtension());
+    writer.writeAttribute(QStringLiteral("fileName"), getFileName());
+    writer.writeAttribute(QStringLiteral("fileExt"), getFileExtension());
     Uml::ID::Type pkgId = Uml::ID::None;
     if (m_package)
         pkgId = m_package->id();
-    writer.writeAttribute(QLatin1String("package"), Uml::ID::toString(pkgId));
-    writer.writeAttribute(QLatin1String("writeOutCode"), getWriteOutCode() ? QLatin1String("true")
-                                                                             : QLatin1String("false"));
-    writer.writeAttribute(QLatin1String("id"), ID());
+    writer.writeAttribute(QStringLiteral("package"), Uml::ID::toString(pkgId));
+    writer.writeAttribute(QStringLiteral("writeOutCode"), getWriteOutCode() ? QStringLiteral("true")
+                                                                             : QStringLiteral("false"));
+    writer.writeAttribute(QStringLiteral("id"), ID());
 
     // set the a header
     // which we will store in its own separate child node block
-    writer.writeStartElement(QLatin1String("header"));
-    getHeader()->saveToXMI1(writer); // comment
+    writer.writeStartElement(QStringLiteral("header"));
+    getHeader()->saveToXMI(writer); // comment
     writer.writeEndElement();
 
     // doc codePolicy?
@@ -385,12 +385,12 @@ void CodeDocument::setAttributesOnNode (QXmlStreamWriter& writer)
 void CodeDocument::setAttributesFromNode (QDomElement & root)
 {
     // now set local attributes
-    setFileName(root.attribute(QLatin1String("fileName")));
-    setFileExtension(root.attribute(QLatin1String("fileExt")));
-    QString pkgStr = root.attribute(QLatin1String("package"));
-    if (!pkgStr.isEmpty() && pkgStr != QLatin1String("-1")) {
+    setFileName(root.attribute(QStringLiteral("fileName")));
+    setFileExtension(root.attribute(QStringLiteral("fileExt")));
+    QString pkgStr = root.attribute(QStringLiteral("package"));
+    if (!pkgStr.isEmpty() && pkgStr != QStringLiteral("-1")) {
         UMLDoc *umldoc = UMLApp::app()->document();
-        if (pkgStr.contains(QRegExp(QLatin1String("\\D")))) {
+        if (pkgStr.contains(QRegExp(QStringLiteral("\\D")))) {
             // suspecting pre-1.5.3 file format where the package name was
             // saved instead of the package ID.
             UMLObject *o = umldoc->findUMLObject(pkgStr);
@@ -401,10 +401,10 @@ void CodeDocument::setAttributesFromNode (QDomElement & root)
             m_package = o->asUMLPackage();
         }
     }
-    const QString trueStr = QLatin1String("true");
-    const QString wrOutCode = root.attribute(QLatin1String("writeOutCode"), trueStr);
+    const QString trueStr = QStringLiteral("true");
+    const QString wrOutCode = root.attribute(QStringLiteral("writeOutCode"), trueStr);
     setWriteOutCode(wrOutCode == trueStr);
-    setID(root.attribute(QLatin1String("id")));
+    setID(root.attribute(QStringLiteral("id")));
 
     // load comment now
     // by looking for our particular child element
@@ -412,10 +412,10 @@ void CodeDocument::setAttributesFromNode (QDomElement & root)
     QDomElement element = node.toElement();
     while (!element.isNull()) {
         QString tag = element.tagName();
-        if (tag == QLatin1String("header")) {
+        if (tag == QStringLiteral("header")) {
             QDomNode cnode = element.firstChild();
             QDomElement celem = cnode.toElement();
-            getHeader()->loadFromXMI1(celem);
+            getHeader()->loadFromXMI(celem);
             break;
         }
         node = element.nextSibling();
@@ -428,12 +428,11 @@ void CodeDocument::setAttributesFromNode (QDomElement & root)
 
 /**
  * Save the XMI representation of this object.
- * @param doc   the xmi document
- * @param root  the starting point to append
+ * @param writer QXmlStreamWriter serialization target
  */
-void CodeDocument::saveToXMI1(QXmlStreamWriter& writer)
+void CodeDocument::saveToXMI(QXmlStreamWriter& writer)
 {
-    writer.writeStartElement(QLatin1String("codedocument"));
+    writer.writeStartElement(QStringLiteral("codedocument"));
     setAttributesOnNode(writer);
     writer.writeEndElement();
 }
@@ -516,7 +515,7 @@ TextBlock * CodeDocument::findTextBlockByTag(const QString &tag, bool descendInt
  */
 TextBlock * CodeDocument::findCodeClassFieldTextBlockByTag (const QString &tag)
 {
-    uWarning() << "Called findCodeClassFieldMethodByTag(" << tag << ") for a regular CodeDocument";
+    logWarn1("Called findCodeClassFieldMethodByTag(%1) for a regular CodeDocument", tag);
     return 0;
 }
 
